docx\_parser\_converter.docx\_parsers.document package
======================================================

Submodules
----------

.. toctree::
   :maxdepth: 4

   docx_parser_converter.docx_parsers.document.document_numbering_parser
   docx_parser_converter.docx_parsers.document.document_parser
   docx_parser_converter.docx_parsers.document.margins_parser
   docx_parser_converter.docx_parsers.document.paragraph_parser
   docx_parser_converter.docx_parsers.document.run_parser

Module contents
---------------

.. automodule:: docx_parser_converter.docx_parsers.document
   :members:
   :undoc-members:
   :show-inheritance:
